==> google-cloud-sdk-116.0.0.tgz: google-cloud-sdk/lib/surface/container/builds/__init__.py <==
# Copyright 2016 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""The command group for cloud container builds."""

from googlecloudsdk.calliope import base
from googlecloudsdk.core import apis as core_apis
from googlecloudsdk.core import properties
from googlecloudsdk.core import resolvers
from googlecloudsdk.core import resources


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Builds(base.Group):
  """Create and manage container builds."""

  def Filter(self, context, args):
    """Modify the context that will be given to this group's commands when run.

    Args:
      context: {str:object}, A set of key-value pairs that can be used for
          common initialization among commands.
      args: argparse.Namespace: The same namespace given to the corresponding
          .Run() invocation.

    Returns:
      The refined command context.
    """

    # client = core_apis.GetClientInstance('cloudbuild', 'v1')
    # registry = resources.REGISTRY.CloneAndSwitchAPIs(client)
    # registry = registry.CloneAndSwitchAPIs(
    #     core_apis.GetClientInstance('storage', 'v1'))

    resources.REGISTRY.SetParamDefault(
        api='cloudbuild', collection=None, param='projectId',
        resolver=resolvers.FromProperty(properties.VALUES.core.project))

    context['registry'] = resources.REGISTRY

    return context

==> google-cloud-sdk-148.0.1.tgz: google-cloud-sdk/lib/surface/container/builds/__init__.py <==
# Copyright 2016 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""The command group for cloud container builds."""

from googlecloudsdk.api_lib.util import apis as core_apis
from googlecloudsdk.calliope import base
from googlecloudsdk.core import properties
from googlecloudsdk.core import resolvers
from googlecloudsdk.core import resources


@base.ReleaseTracks(
    base.ReleaseTrack.ALPHA,
    base.ReleaseTrack.BETA,
    base.ReleaseTrack.GA)
class Builds(base.Group):
  """Create and manage container builds."""

  def Filter(self, context, args):
    """Modify the context that will be given to this group's commands when run.

    Args:
      context: {str:object}, A set of key-value pairs that can be used for
          common initialization among commands.
      args: argparse.Namespace: The same namespace given to the corresponding
          .Run() invocation.

    Returns:
      The refined command context.
    """

    if not properties.VALUES.core.project.Get():
      raise properties.RequiredPropertyError(
          properties.VALUES.core.project,
          flag='--project')

    resources.REGISTRY.SetParamDefault(
        api='cloudbuild', collection=None, param='projectId',
        resolver=resolvers.FromProperty(properties.VALUES.core.project))

    context['registry'] = resources.REGISTRY

    return context
